##  Applicable Use Cases
Use objectives in the following use cases:
  * Application rationalization: [Step 1: Understand Your Strategy](https://help.sap.com/docs/leanix/ea/application-rationalization-understand-strategy?locale=en-US&state=PRODUCTION&version=CLOUD "Aligning IT and business strategy in SAP LeanIX ensures application rationalization initiatives support enterprise architecture goals and deliver measurable outcomes.")
  * Application modernization: [Step 1: Understand Your Strategy](https://help.sap.com/docs/leanix/ea/application-modernization-understand-strategy?locale=en-US&state=PRODUCTION&version=CLOUD "Get clear on what modernization means for your organization to guide decisions and priorities during transformation initiatives.")
  * [ERP Transformation](https://help.sap.com/docs/leanix/ea/erp-transformation?locale=en-US&state=PRODUCTION&version=CLOUD "Step-by-step guide for ERP Transformation using SAP LeanIX.")
